@@ -1,20 +1,23 @@
 from splinter.driver.webdriver.firefox import WebDriver as FirefoxWebDriver
 from splinter.driver.webdriver.chrome import WebDriver as ChromeWebDriver
-
-try:
-    from splinter.driver.zopetestbrowser import ZopeTestBrowser
-    has_zope_browser = True
-except ImportError:
-    has_zope_browser = False
+from splinter.exceptions import DriverNotFoundError
 
 _DRIVERS = {
     'webdriver.firefox': FirefoxWebDriver,
     'webdriver.chrome': ChromeWebDriver
 }
 
-if has_zope_browser:
+try:
+    from splinter.driver.zopetestbrowser import ZopeTestBrowser
     _DRIVERS['zope.testbrowser'] = ZopeTestBrowser
+except ImportError:
+    pass
+
 
 def Browser(driver_name='webdriver.firefox'):
-    driver = _DRIVERS[driver_name]
-    return driver()
+
+    try:
+        driver = _DRIVERS[driver_name]
+        return driver()
+    except KeyError:
+        raise DriverNotFoundError
