@@ -78,6 +78,12 @@ EXAMPLE_HTML = """\
     <a class='remove-async-element' href="#">remove async element</a>
     <a class='add-element-mouseover' href="#">addelement (mouseover)</a>
     <iframe id="iframemodal" src="/iframe"></iframe>
+    <div id="inside">
+        <h2>inside</h2>
+        <form>
+            <input id="visible" name="upload" type="text" />
+        </form>
+    </div>
   </body>
 </html>"""
 
@@ -113,22 +119,27 @@ EXAMPLE_ALERT_HTML = """\
 
 app = Flask(__name__)
 
+
 @app.route('/')
 def index():
     return EXAMPLE_HTML
 
+
 @app.route('/iframe')
 def iframed():
     return EXAMPLE_IFRAME_HTML
 
+
 @app.route('/alert')
 def alertd():
     return EXAMPLE_ALERT_HTML
 
+
 @app.route('/name', methods=['GET'])
 def get_name():
     return "My name is: Master Splinter"
 
+
 @app.route('/upload', methods=['GET', 'POST'])
 def upload_file():
     if request.method == 'POST':
@@ -139,24 +150,29 @@ def upload_file():
 
         return '|'.join(buffer)
 
+
 @app.route('/foo')
 def foo():
     return "BAR!"
 
+
 class Env(object):
     pass
 
+
 env = Env()
 env.process = None
 env.host, env.port = 'localhost', 5000
 env.browser = None
 
+
 def start_flask_app(host, port):
     """Runs the server."""
     app.run(host=host, port=port)
     app.config['DEBUG'] = False
     app.config['TESTING'] = False
 
+
 def wait_until_start():
     while True:
         try:
@@ -165,6 +181,7 @@ def wait_until_start():
         except IOError:
             pass
 
+
 def wait_until_stop():
     while True:
         try:
@@ -174,12 +191,14 @@ def wait_until_stop():
         except IOError:
             break
 
+
 def start_server():
     env.process = Process(target=start_flask_app, args=(env.host, env.port))
     env.process.daemon = True
     env.process.start()
     wait_until_start()
 
+
 def stop_server():
     env.process.terminate()
     wait_until_stop()
